@@ -511,15 +511,15 @@ class AnalysisSTEAM:
         # Build simulation file
         len_simulation_numbers = len(step.simulation_numbers)
         if len_simulation_numbers > 0:
-            simulation_number = step.simulation_numbers
-            if 'LEDET' in step.software:
-                flag_yaml = True  # Hard-coded for the moment
-                flag_json = False  # Hard-coded for the moment
-                self.setup_sim_LEDET(simulation_name=step.simulation_name, sim_number=simulation_number, flag_yaml=flag_yaml, flag_json=flag_json)
-            if 'PyBBQ' in step.software:
-                self.setup_sim_PyBBQ(simulation_name=step.simulation_name, sim_number=simulation_number)
-            if 'PSPICE' in step.software:
-                self.setup_sim_PSPICE(simulation_name=step.simulation_name, sim_number=simulation_number)
+            for simulation_number in step.simulation_numbers:
+                if 'LEDET' in step.software:
+                    flag_yaml = True  # Hard-coded for the moment
+                    flag_json = False  # Hard-coded for the moment
+                    self.setup_sim_LEDET(simulation_name=step.simulation_name, sim_number=simulation_number, flag_yaml=flag_yaml, flag_json=flag_json)
+                if 'PyBBQ' in step.software:
+                    self.setup_sim_PyBBQ(simulation_name=step.simulation_name, sim_number=simulation_number)
+                if 'PSPICE' in step.software:
+                    self.setup_sim_PSPICE(simulation_name=step.simulation_name, sim_number=simulation_number)
 
     def setup_sim_LEDET(self, simulation_name, sim_number, flag_yaml=True, flag_json=False):
         '''
@@ -554,8 +554,8 @@ class AnalysisSTEAM:
             shutil.copyfile(file_name_temp, file_name_local)
             print('Simulation file {} copied.'.format(file_name_local))
 
-            os.remove(file_name_temp)
-            print('Temporary file {} deleted.'.format(file_name_temp))
+            # os.remove(file_name_temp)
+            # print('Temporary file {} deleted.'.format(file_name_temp))
 
 
     def setup_sim_PSPICE(self, simulation_name, sim_number):
@@ -585,8 +585,8 @@ class AnalysisSTEAM:
         shutil.copyfile(file_name_temp, file_name_local)
         print('Simulation file {} copied.'.format(file_name_local))
 
-        os.remove(file_name_temp)
-        print('Temporary file {} deleted.'.format(file_name_temp))
+        # os.remove(file_name_temp)
+        # print('Temporary file {} deleted.'.format(file_name_temp))
 
         # Copy lib files from the output folder
         list_lib_files = [entry for entry in os.listdir(output_folder) if (simulation_name in entry) and ('.lib' in entry)]
@@ -631,8 +631,8 @@ class AnalysisSTEAM:
         shutil.copyfile(file_name_temp, file_name_local)
         print('Simulation file {} copied.'.format(file_name_local))
 
-        os.remove(file_name_temp)
-        print('Temporary file {} deleted.'.format(file_name_temp))
+        # os.remove(file_name_temp)
+        # print('Temporary file {} deleted.'.format(file_name_temp))
 
 
     def run_sim(self, software: str, simulation_name: str, sim_number: int, simFileType: str = None, verbose: bool = False):
