@@ -8,9 +8,11 @@ from steam_sdk.data.DataModelConductor import DataModelConductor
 from steam_sdk.data.DataModelMagnet import *
 from steam_sdk.data.DataModelCircuit import DataModelCircuit
 from steam_sdk.data.DataRoxieParser import RoxieData
+from steam_sdk.builders.BuilderFiQuS import BuilderFiQuS
 from steam_sdk.builders.BuilderLEDET import BuilderLEDET
-from steam_sdk.builders.BuilderSIGMA import BuilderSIGMA
 from steam_sdk.builders.BuilderProteCCT import BuilderProteCCT
+from steam_sdk.builders.BuilderSIGMA import BuilderSIGMA
+from steam_sdk.parsers.ParserFiQuS import ParserFiQuS
 from steam_sdk.parsers.ParserLEDET import ParserLEDET, copy_modified_map2d_ribbon_cable, copy_map2d
 from steam_sdk.parsers.ParserPSPICE import ParserPSPICE
 from steam_sdk.parsers.ParserProteCCT import ParserProteCCT
@@ -94,9 +96,10 @@ class BuilderModel:
 
                 # Build model
                 for s in self.software:
+                    if s == 'FiQuS':    self.buildFiQuS()
                     if s == 'LEDET':    self.buildLEDET(case_model=self.case_model)
-                    if s == 'SIGMA':    self.buildSIGMA()
                     if s == 'ProteCCT': self.buildProteCCT()
+                    if s == 'SIGMA':    self.buildSIGMA()
 
                 if flag_dump_all:
                     self.dumpAll()
@@ -149,7 +152,6 @@ class BuilderModel:
                     if s == 'LEDET':    self.buildLEDET(case_model=self.case_model)
                     if s == 'PyBBQ':    self.buildPyBBQ()
 
-
     def set_input_paths(self, case_model: str):
         """
             Sets input paths and displays related information
@@ -179,7 +181,8 @@ class BuilderModel:
             pass  # no paths to assign
         elif case_model == 'conductor':
             if self.conductor_data.Sources.magnetic_field_fromROXIE:
-                self.path_map2d = Path(self.path_magnet / self.conductor_data.Sources.magnetic_field_fromROXIE).resolve()
+                self.path_map2d = Path(
+                    self.path_magnet / self.conductor_data.Sources.magnetic_field_fromROXIE).resolve()
         else:
             raise Exception('case_model ({}) no supported'.format(case_model))
 
@@ -215,7 +218,6 @@ class BuilderModel:
             print('path_map2d:    {}'.format(self.path_map2d))
             print('path_settings: {}'.format(self.path_settings))
 
-
     def loadModelData(self, case_model: str):
         """
             Loads model data from yaml file to model data object
@@ -242,7 +244,6 @@ class BuilderModel:
                 dictionary_yaml = yaml.safe_load(stream)
                 self.conductor_data = DataModelConductor(**dictionary_yaml)
 
-
     def loadRoxieData(self):
         """
             Apply roxie parser to fetch magnet information for the given magnet and stores in member variable
@@ -266,8 +267,20 @@ class BuilderModel:
         ############################################################
         # Load information from ROXIE input files using ROXIE parser
         roxie_parser = ParserRoxie()
-        self.roxie_data = roxie_parser.getData(dir_data=self.path_data, dir_cadata=self.path_cadata, dir_iron=self.path_iron)
+        self.roxie_data = roxie_parser.getData(dir_data=self.path_data, dir_cadata=self.path_cadata,
+                                               dir_iron=self.path_iron)
 
+    def buildFiQuS(self):
+        """
+            Building a FiQuS model
+        """
+        builder_FiQuS = BuilderFiQuS(input_model_data=self.model_data, input_roxie_data=self.roxie_data,
+                                     flag_build=self.flag_build, verbose=self.verbose)
+
+        # Write output files
+        parser_FiQuS = ParserFiQuS(builder_FiQuS)
+        parser_FiQuS.writeFiQuS2yaml(full_path_file_name=os.path.join(self.output_path,
+                                     self.model_data.GeneralParameters.magnet_name), verbose=self.verbose)
 
     def buildLEDET(self, case_model: str = 'magnet'):
         """
@@ -288,7 +301,7 @@ class BuilderModel:
                 # List of flags that are True is the cable type is "Ribbon"
                 list_flag_ribbon = []
                 for i, cond in enumerate(self.model_data.CoilWindings.conductor_to_group):
-                    list_flag_ribbon.append(self.model_data.Conductors[cond-1].cable.type == 'Ribbon')
+                    list_flag_ribbon.append(self.model_data.Conductors[cond - 1].cable.type == 'Ribbon')
 
                 nT_from_original_map2d, nStrands_inGroup_original_map2d, _, _, _, _, _, _ = getParametersFromMap2d(
                     map2dFile=self.path_map2d, headerLines=self.model_data.Options_LEDET.field_map_files.headerLines,
@@ -315,17 +328,18 @@ class BuilderModel:
                                                                     suffix=suffix, verbose=self.verbose)
 
             elif self.model_data.Options_LEDET.field_map_files.flag_modify_map2d_ribbon_cable == 0 or self.model_data.Options_LEDET.field_map_files.flag_modify_map2d_ribbon_cable == None:
-                file_name_output = copy_map2d(magnet_name, self.path_map2d,
-                                              self.output_path, self.model_data.Options_LEDET.field_map_files.flagIron,
-                                              self.model_data.Options_LEDET.field_map_files.flagSelfField, suffix=suffix,
-                                              verbose=self.verbose)
+                file_name_output = copy_map2d(magnet_name, self.path_map2d, self.output_path,
+                                              self.model_data.Options_LEDET.field_map_files.flagIron,
+                                              self.model_data.Options_LEDET.field_map_files.flagSelfField,
+                                              suffix=suffix, verbose=self.verbose)
 
             self.map2d_file_modified = os.path.join(self.output_path, file_name_output)
 
             # Copy the additional geometry and magnetic field csv file, if defined in the input file
             if self.model_data.Options_LEDET.simulation_3D.sim3D_flag_Import3DGeometry == 1:
-                name_geometry_csv_file = magnet_name + '_' + str(self.conductor_data.Options_LEDET.simulation_3D.sim3D_import3DGeometry_modelNumber) + '.csv'
-                input_path_full  = os.path.join(self.path_magnet, name_geometry_csv_file)
+                name_geometry_csv_file = magnet_name + '_' + str(
+                    self.conductor_data.Options_LEDET.simulation_3D.sim3D_import3DGeometry_modelNumber) + '.csv'
+                input_path_full = os.path.join(self.path_magnet, name_geometry_csv_file)
                 output_path_full = os.path.join(self.output_path, name_geometry_csv_file)
                 shutil.copy2(input_path_full, output_path_full)
                 if self.verbose:
@@ -333,13 +347,13 @@ class BuilderModel:
 
             builder_ledet = BuilderLEDET(path_magnet=self.path_magnet, input_model_data=self.model_data,
                                          input_roxie_data=self.roxie_data, input_map2d=self.map2d_file_modified,
-                                         smic_write_path=nameFileSMIC, flag_build=self.flag_build, flag_plot_all=self.flag_plot_all,
-                                         verbose=self.verbose,
-                                         case_model=case_model)
+                                         smic_write_path=nameFileSMIC, flag_build=self.flag_build,
+                                         flag_plot_all=self.flag_plot_all, verbose=self.verbose, case_model=case_model)
 
             # Copy or modify+copy magnet-name_E....map2d files
-            number_input_files = len([entry for entry in os.listdir(self.path_magnet) if os.path.isfile(os.path.join(self.path_magnet, entry))])
-            for file in range(number_input_files+1):
+            number_input_files = len([entry for entry in os.listdir(self.path_magnet) if
+                                      os.path.isfile(os.path.join(self.path_magnet, entry))])
+            for file in range(number_input_files + 1):
                 suffix = '_E{}'.format(file)
                 path_map2d_E = os.path.join(self.path_magnet, magnet_name + suffix + '.map2d')
                 if os.path.isfile(path_map2d_E):
@@ -352,23 +366,27 @@ class BuilderModel:
                                                          list_flag_ribbon,
                                                          suffix=suffix, verbose=self.verbose)
                     elif self.model_data.Options_LEDET.field_map_files.flag_modify_map2d_ribbon_cable == 0 or self.model_data.Options_LEDET.field_map_files.flag_modify_map2d_ribbon_cable == None:
-                        copy_map2d(magnet_name, path_map2d_E, self.output_path, self.model_data.Options_LEDET.field_map_files.flagIron,
-                                              self.model_data.Options_LEDET.field_map_files.flagSelfField, suffix=suffix,
-                                              verbose=self.verbose)
+                        copy_map2d(magnet_name, path_map2d_E, self.output_path,
+                                   self.model_data.Options_LEDET.field_map_files.flagIron,
+                                   self.model_data.Options_LEDET.field_map_files.flagSelfField, suffix=suffix,
+                                   verbose=self.verbose)
 
             # Write output excel file
             parser_ledet = ParserLEDET(builder_ledet)
             nameFileLEDET = os.path.join(self.output_path, magnet_name + '.xlsx')  # full path of the LEDET input file to write
-            parser_ledet.writeLedet2Excel(full_path_file_name=nameFileLEDET, verbose=self.verbose, SkipConsistencyCheck=True)
+            parser_ledet.writeLedet2Excel(full_path_file_name=nameFileLEDET, verbose=self.verbose,
+                                          SkipConsistencyCheck=True)
 
             # Write output yaml file
             nameFileLedetYaml = os.path.join(self.output_path, magnet_name + '.yaml')  # full path of the LEDET input file to write
-            parser_ledet.write2yaml(full_path_file_name=nameFileLedetYaml, verbose=self.verbose, SkipConsistencyCheck=True)
+            parser_ledet.write2yaml(full_path_file_name=nameFileLedetYaml, verbose=self.verbose,
+                                    SkipConsistencyCheck=True)
 
             # Write output json file
             if self.flag_json:
                 nameFileLedetJson = os.path.join(self.output_path, magnet_name + '.json')  # full path of the LEDET input file to write
-                parser_ledet.write2json(full_path_file_name=nameFileLedetJson, verbose=self.verbose, SkipConsistencyCheck=True)
+                parser_ledet.write2json(full_path_file_name=nameFileLedetJson, verbose=self.verbose,
+                                        SkipConsistencyCheck=True)
 
         elif case_model == 'conductor':
             conductor_name = self.conductor_data.GeneralParameters.conductor_name
@@ -391,8 +409,9 @@ class BuilderModel:
 
             # Copy the additional geometry and magnetic field csv file, if defined in the input file
             if self.conductor_data.Options_LEDET.simulation_3D.sim3D_flag_Import3DGeometry == 1:
-                name_geometry_csv_file = conductor_name + '_' + str(self.conductor_data.Options_LEDET.simulation_3D.sim3D_import3DGeometry_modelNumber) + '.csv'
-                input_path_full  = os.path.join(self.path_magnet, name_geometry_csv_file)
+                name_geometry_csv_file = conductor_name + '_' + str(
+                    self.conductor_data.Options_LEDET.simulation_3D.sim3D_import3DGeometry_modelNumber) + '.csv'
+                input_path_full = os.path.join(self.path_magnet, name_geometry_csv_file)
                 output_path_full = os.path.join(self.output_path, name_geometry_csv_file)
                 shutil.copy2(input_path_full, output_path_full)
                 if self.verbose:
@@ -407,16 +426,19 @@ class BuilderModel:
             # Write output excel file
             parser_ledet = ParserLEDET(builder_ledet)
             nameFileLEDET = os.path.join(self.output_path, conductor_name + '.xlsx')  # full path of the LEDET input file to write
-            parser_ledet.writeLedet2Excel(full_path_file_name=nameFileLEDET, verbose=self.verbose, SkipConsistencyCheck=True)
+            parser_ledet.writeLedet2Excel(full_path_file_name=nameFileLEDET, verbose=self.verbose,
+                                          SkipConsistencyCheck=True)
 
             # Write output yaml file
             nameFileLedetYaml = os.path.join(self.output_path, conductor_name + '.yaml')  # full path of the LEDET input file to write
-            parser_ledet.write2yaml(full_path_file_name=nameFileLedetYaml, verbose=self.verbose, SkipConsistencyCheck=True)
+            parser_ledet.write2yaml(full_path_file_name=nameFileLedetYaml, verbose=self.verbose,
+                                    SkipConsistencyCheck=True)
 
             # Write output json file
             if self.flag_json:
                 nameFileLedetJson = os.path.join(self.output_path, conductor_name + '.json')  # full path of the LEDET input file to write
-                parser_ledet.write2json(full_path_file_name=nameFileLedetJson, verbose=self.verbose, SkipConsistencyCheck=True)
+                parser_ledet.write2json(full_path_file_name=nameFileLedetJson, verbose=self.verbose,
+                                        SkipConsistencyCheck=True)
 
         else:
             raise Exception('Case model {} is not supported when building a LEDET model.'.format(case_model))
@@ -426,21 +448,15 @@ class BuilderModel:
             Building a ProteCCT model
         """
         magnet_name = self.model_data.GeneralParameters.magnet_name
-        builder_protecct = BuilderProteCCT(input_model_data=self.model_data, flag_build=self.flag_build, verbose=self.verbose)
+        builder_protecct = BuilderProteCCT(input_model_data=self.model_data, flag_build=self.flag_build,
+                                           verbose=self.verbose)
 
         # Write output excel file
         parser_protecct = ParserProteCCT(builder_protecct)
-        nameFileProteCCT = os.path.join(self.output_path, magnet_name + '.xlsx')  # full path of the ProteCCT input file to write
-        parser_protecct.writeProtecct2Excel(full_path_file_name=nameFileProteCCT, verbose=self.verbose, SkipConsistencyCheck=True)
-
-
-    def buildSIGMA(self):
-        """
-            Building a SIGMA model
-        """
-        BuilderSIGMA(input_model_data=self.model_data, input_roxie_data=self.roxie_data,
-                     settings_dict=self.settings_dict, output_path=self.output_path,
-                     flag_build=self.flag_build, verbose=self.verbose)
+        nameFileProteCCT = os.path.join(self.output_path,
+                                        magnet_name + '.xlsx')  # full path of the ProteCCT input file to write
+        parser_protecct.writeProtecct2Excel(full_path_file_name=nameFileProteCCT, verbose=self.verbose,
+                                            SkipConsistencyCheck=True)
 
     def buildPSPICE(self):
         """
@@ -450,7 +466,8 @@ class BuilderModel:
         circuit_name = self.circuit_data.GeneralParameters.circuit_name
 
         # Write output .cir file
-        parser_pspice = ParserPSPICE(circuit_data=circuit_data, path_input=self.path_magnet, output_path=self.output_path)
+        parser_pspice = ParserPSPICE(circuit_data=circuit_data, path_input=self.path_magnet,
+                                     output_path=self.output_path)
         nameFilePSPICE = os.path.join(self.output_path, circuit_name + '.cir')  # full path of the PSPICE netlist to write
         parser_pspice.write2pspice(full_path_file_name=nameFilePSPICE, verbose=self.verbose)
 
@@ -462,13 +479,22 @@ class BuilderModel:
             Building a PyBBQ model
         """
         conductor_name = self.conductor_data.GeneralParameters.conductor_name
-        builder_PyBBQ = BuilderPyBBQ(input_model_data=self.conductor_data, flag_build=self.flag_build, verbose=self.verbose)
+        builder_PyBBQ = BuilderPyBBQ(input_model_data=self.conductor_data, flag_build=self.flag_build,
+                                     verbose=self.verbose)
 
         # Write output yaml file
         parser_PyBBQ = ParserPyBBQ(builder_PyBBQ)
         nameFilePyBBQ = os.path.join(self.output_path, conductor_name + '.yaml')  # full path of the PyBBQ input file to write
         parser_PyBBQ.writePyBBQ2yaml(full_path_file_name=nameFilePyBBQ, verbose=self.verbose)
 
+    def buildSIGMA(self):
+        """
+            Building a SIGMA model
+        """
+        BuilderSIGMA(input_model_data=self.model_data, input_roxie_data=self.roxie_data,
+                     settings_dict=self.settings_dict, output_path=self.output_path,
+                     flag_build=self.flag_build, verbose=self.verbose)
+
     def dumpAll(self):
         """
             Writes model data and data from Roxie parser in a combined .yaml file
@@ -494,9 +520,8 @@ class BuilderModel:
             Path(self.dump_all_path).mkdir(parents=True)
 
         # Write output .yaml file
-        dump_all_full_path = os.path.join(dump_all_path, self.model_data.GeneralParameters.magnet_name + '_all_data.yaml')
+        dump_all_full_path = os.path.join(dump_all_path,
+                                          self.model_data.GeneralParameters.magnet_name + '_all_data.yaml')
         # with open(dump_all_full_path, 'w') as outfile:
         #     yaml.dump(all_data_dict, outfile, default_flow_style=False, sort_keys=False)
         dict_to_yaml(all_data_dict, dump_all_full_path, list_exceptions=['Conductors'])
-
-
