@@ -94,6 +94,7 @@ class LEDETInputs:
     sim3D_f_cooling_up: np.ndarray = np.array([])
     sim3D_f_cooling_left: np.ndarray = np.array([])
     sim3D_f_cooling_right: np.ndarray = np.array([])
+    sim3D_f_cooling_LeadEnds: np.ndarray = np.array([])
     sim3D_fExToIns: float = None
     sim3D_fExUD: float = None
     sim3D_fExLR: float = None
@@ -102,6 +103,8 @@ class LEDETInputs:
     sim3D_min_nodesPerStraightPart: int = None
     sim3D_min_nodesPerEndsPart: int = None
     sim3D_idxFinerMeshHalfTurn: np.ndarray = np.array([])
+    sim3D_flag_checkNodeProximity: int = None
+    sim3D_nodeProximityThreshold: float = None
     sim3D_Tpulse_sPosition: float = None
     sim3D_Tpulse_peakT: float = None
     sim3D_Tpulse_width: float = None
@@ -173,6 +176,7 @@ class LEDETOptions:
     flag_saveFigures: int = None
     flag_saveMatFile: int = None
     flag_saveTxtFiles: int = None
+    flag_saveResultsToMesh: int = None
     flag_generateReport: int = None
     flag_hotSpotTemperatureInEachGroup: int = None
     flag_3D: int = None
@@ -201,6 +205,11 @@ class LEDETVariables:
     variableToSaveTxt: np.ndarray = np.array([])
     typeVariableToSaveTxt: np.ndarray = np.array([])
     variableToInitialize: np.ndarray = np.array([])
+    writeToMesh_fileNameMeshPositions: np.ndarray = np.array([])
+    writeToMesh_suffixFileNameOutput: np.ndarray = np.array([])
+    writeToMesh_selectedVariables: np.ndarray = np.array([])
+    writeToMesh_selectedTimeSteps: np.ndarray = np.array([])
+    writeToMesh_selectedMethod: np.ndarray = np.array([])
 
 @dataclass
 class LEDETAuxiliary:
