@@ -1,5 +1,5 @@
 from pydantic import BaseModel
-from typing import (List)
+from typing import (List, Dict)
 
 
 ############################
@@ -44,7 +44,7 @@ class Stimuli(BaseModel):
 # Libraries
 class Libraries(BaseModel):
     """
-        Level 1: Component libraries
+        Level 1: Component_OLD libraries
     """
     component_libraries: List[str] = []
 
@@ -67,13 +67,12 @@ class InitialConditions(BaseModel):
 
 
 ############################
-# Netlist, defined as a list of Component objects
+# Netlist, defined as a list of Component_OLD objects
 class Component(BaseModel):
     """
         Level 1: Circuit component
     """
     type: str = None
-    name: str = None
     nodes: List[str] = []
     value: str = None
     parameters: dict = None
@@ -147,7 +146,7 @@ class DataModelCircuit(BaseModel):
     Libraries: Libraries = Libraries()
     GlobalParameters: Global_Parameters = Global_Parameters()
     InitialConditions: InitialConditions = InitialConditions()
-    Netlist: List[Component] = [Component()]
+    Netlist: Dict[str, Component] = {}
     Options: Options = Options()
     Analysis: Analysis = Analysis()
     PostProcess: PostProcess = PostProcess()
