@@ -47,6 +47,7 @@ class General(BaseModel):
     magnet_name: str = None
     circuit_name: str = None
     model: Model = Model()
+    magnet_type: str = None
     T_initial: float = None               # T00 (LEDET), Top (SIGMA)
     magnetic_length: float = None   # l_magnet (LEDET), magLength (SIGMA), magneticLength (ProteCCT)
     magnet_inductance: MagnetInductance = MagnetInductance()
@@ -384,6 +385,7 @@ class PostProcessingLEDET(BaseModel):
     flag_saveMatFile: int = None
     flag_saveTxtFiles: int = None
     flag_generateReport: int = None
+    flag_saveResultsToMesh: int = None
     tQuench: List[float] = []
     initialQuenchTemp: List[float] = []
     flag_hotSpotTemperatureInEachGroup: int = None
@@ -401,10 +403,11 @@ class Simulation3DLEDET(BaseModel):
 
     # Variables in the "Inputs" sheet
     sim3D_uThreshold: float = None
-    sim3D_f_cooling_down: float = None
-    sim3D_f_cooling_up: float = None
-    sim3D_f_cooling_left: float = None
-    sim3D_f_cooling_right: float = None
+    sim3D_f_cooling_down: Union[float, int] = None
+    sim3D_f_cooling_up: Union[float, int] = None
+    sim3D_f_cooling_left: Union[float, int] = None
+    sim3D_f_cooling_right: Union[float, int] = None
+    sim3D_f_cooling_LeadEnds: List[int] = []
     sim3D_fExToIns: float = None
     sim3D_fExUD: float = None
     sim3D_fExLR: float = None
@@ -413,6 +416,8 @@ class Simulation3DLEDET(BaseModel):
     sim3D_min_nodesPerStraightPart: float = None
     sim3D_min_nodesPerEndsPart: float = None
     sim3D_idxFinerMeshHalfTurn: List[int] = []
+    sim3D_flag_checkNodeProximity: int = None
+    sim3D_nodeProximityThreshold: float = None
     sim3D_Tpulse_sPosition: float = None
     sim3D_Tpulse_peakT: float = None
     sim3D_Tpulse_width: float = None
@@ -453,6 +458,11 @@ class VariablesToSaveLEDET(BaseModel):
     variableToSaveTxt: List[str] = []
     typeVariableToSaveTxt: List[int] = []
     variableToInitialize: List[str] = []
+    writeToMesh_fileNameMeshPositions: List[str] = []
+    writeToMesh_suffixFileNameOutput: List[str] = []
+    writeToMesh_selectedVariables: List[str] = []
+    writeToMesh_selectedTimeSteps: List[str] = []
+    writeToMesh_selectedMethod: List[str] = []
 
 
 class LEDET(BaseModel):
