@@ -216,6 +216,7 @@ def lookupModelDataToLEDET(key: str, mode='data2ledet'):
         'Options_LEDET.post_processing.flag_saveFigures': 'flag_saveFigures',
         'Options_LEDET.post_processing.flag_saveMatFile': 'flag_saveMatFile',
         'Options_LEDET.post_processing.flag_saveTxtFiles': 'flag_saveTxtFiles',
+        'Options_LEDET.post_processing.flag_saveResultsToMesh': 'flag_saveResultsToMesh',
         'Options_LEDET.post_processing.flag_generateReport': 'flag_generateReport',
         'Options_LEDET.post_processing.tQuench': 'tQuench',
         'Options_LEDET.post_processing.initialQuenchTemp': 'initialQuenchTemp',
@@ -230,6 +231,7 @@ def lookupModelDataToLEDET(key: str, mode='data2ledet'):
         'Options_LEDET.simulation_3D.sim3D_f_cooling_up': 'sim3D_f_cooling_up',
         'Options_LEDET.simulation_3D.sim3D_f_cooling_left': 'sim3D_f_cooling_left',
         'Options_LEDET.simulation_3D.sim3D_f_cooling_right': 'sim3D_f_cooling_right',
+        'Options_LEDET.simulation_3D.sim3D_f_cooling_LeadEnds': 'sim3D_f_cooling_LeadEnds',
         'Options_LEDET.simulation_3D.sim3D_fExToIns': 'sim3D_fExToIns',
         'Options_LEDET.simulation_3D.sim3D_fExUD': 'sim3D_fExUD',
         'Options_LEDET.simulation_3D.sim3D_fExLR': 'sim3D_fExLR',
@@ -238,6 +240,8 @@ def lookupModelDataToLEDET(key: str, mode='data2ledet'):
         'Options_LEDET.simulation_3D.sim3D_min_nodesPerStraightPart': 'sim3D_min_nodesPerStraightPart',
         'Options_LEDET.simulation_3D.sim3D_min_nodesPerEndsPart': 'sim3D_min_nodesPerEndsPart',
         'Options_LEDET.simulation_3D.sim3D_idxFinerMeshHalfTurn': 'sim3D_idxFinerMeshHalfTurn',
+        'Options_LEDET.simulation_3D.sim3D_flag_checkNodeProximity': 'sim3D_flag_checkNodeProximity',
+        'Options_LEDET.simulation_3D.sim3D_nodeProximityThreshold': 'sim3D_nodeProximityThreshold',
         'Options_LEDET.simulation_3D.sim3D_Tpulse_sPosition': 'sim3D_Tpulse_sPosition',
         'Options_LEDET.simulation_3D.sim3D_Tpulse_peakT': 'sim3D_Tpulse_peakT',
         'Options_LEDET.simulation_3D.sim3D_Tpulse_width': 'sim3D_Tpulse_width',
@@ -267,7 +271,12 @@ def lookupModelDataToLEDET(key: str, mode='data2ledet'):
 
         'Options_LEDET.variables_to_save.variableToSaveTxt': 'variableToSaveTxt',
         'Options_LEDET.variables_to_save.typeVariableToSaveTxt': 'typeVariableToSaveTxt',
-        'Options_LEDET.variables_to_save.variableToInitialize': 'variableToInitialize'
+        'Options_LEDET.variables_to_save.variableToInitialize': 'variableToInitialize',
+        'Options_LEDET.variables_to_save.writeToMesh_fileNameMeshPositions': 'writeToMesh_fileNameMeshPositions',
+        'Options_LEDET.variables_to_save.writeToMesh_suffixFileNameOutput': 'writeToMesh_suffixFileNameOutput',
+        'Options_LEDET.variables_to_save.writeToMesh_selectedVariables': 'writeToMesh_selectedVariables',
+        'Options_LEDET.variables_to_save.writeToMesh_selectedTimeSteps': 'writeToMesh_selectedTimeSteps',
+        'Options_LEDET.variables_to_save.writeToMesh_selectedMethod': 'writeToMesh_selectedMethod',
     }
 
     if mode == 'data2ledet':
