@@ -1,3 +1,4 @@
+import os
 import datetime
 
 import numpy as np
@@ -6,6 +7,8 @@ from openpyxl.cell.cell import Cell
 from openpyxl.styles import Font
 from openpyxl.utils import get_column_letter
 
+from steam_sdk.utils.make_folder_if_not_existing import make_folder_if_not_existing
+
 
 def read_row(workSheet, Nrow, St=False):
     '''
@@ -39,7 +42,7 @@ def write2Excel(name_file: str,
 
         Function to write an Excel file composed of multiple sheets
 
-        :param name_file: String defining the name of the ProteCCT input file to be written
+        :param name_file: String defining the name of the .xlsx input file to be written
         :type name_file: string
         # TODO Add entries
         :param verbose: flag that determines whether the output are printed
@@ -49,6 +52,9 @@ def write2Excel(name_file: str,
     '''
     # TODO: description more general
 
+    # If the output folder does not exist, make it now
+    make_folder_if_not_existing(os.path.dirname(name_file))
+
     # In case a string is passed, make it a 1-element list
     if isinstance(name_sheets, str):
         name_sheets = [name_sheets]
