@@ -13,6 +13,7 @@ import numpy as np
 import yaml
 
 from steam_sdk.data.DataModelCircuit import DataModelCircuit, Component
+from steam_sdk.parsers.dict_to_yaml import dict_to_yaml
 
 
 class ParserPSPICE:
@@ -186,38 +187,39 @@ class ParserPSPICE:
                     self.circuit_data.AuxiliaryFiles.files_to_include.append(str(value))
                     continue
 
-                # Read netlist - If this part of the code is reached without hitting "continue", it means that this
-                # line does not define a special command, and hence it defines a component of the netlist
-                if (not self.circuit_data.Netlist[0].name == None) and (not self.flag_read_parametrized_component):  # Append a new component (unless it is the first component)
-                    self.circuit_data.Netlist.append(Component())
+                    # TODO delete
+                # # Read netlist - If this part of the code is reached without hitting "continue", it means that this
+                # # line does not define a special command, and hence it defines a component of the netlist
+                # if (not self.circuit_data.Netlist[0].name == None) and (not self.flag_read_parametrized_component):  # Append a new component (unless it is the first component)
+                #     self.circuit_data.Netlist.append(Component_OLD())
 
                 # Special case: Stimulus-controlled component
                 if 'STIMULUS=' in line.replace(' ', ''):  # this covers the cases "STIMULUS = ", "STIMULUS=", etc
                     line_split = line.rstrip('\n').split('(')  # TODO: Improve the logic, which now fails if the value includes the character "("
-                    name = line_split[0].strip(' ')
+                    name = str(line_split[0].strip(' '))
                     line_split = line_split[1].rstrip('\n').split(')')
                     nodes = line_split[0].split(' ')
                     line_split = line_split[1].split('=')
                     value = line_split[1].strip(' { } ')  # Strip spaces and bracket at the extremities
-                    self.circuit_data.Netlist[-1].type  = 'stimulus-controlled component'
-                    self.circuit_data.Netlist[-1].name  = str(name)
-                    self.circuit_data.Netlist[-1].nodes = nodes
-                    self.circuit_data.Netlist[-1].value = str(value)
+                    self.circuit_data.Netlist[name] = Component()
+                    self.circuit_data.Netlist[name].type = 'stimulus-controlled component'
+                    self.circuit_data.Netlist[name].nodes = nodes
+                    self.circuit_data.Netlist[name].value = str(value)
                     continue
 
                 # Special case: Pulsed power source
                 if 'PULSE' in line.replace(' ', ''):
                     # Note: The following logic works for three different syntaxes: "PULSE(value)", "PULSE (value)" and "PULSE value"
                     line_before, _, line_after = line.rstrip('\n').partition('(')  # Take the part of the string before and after the first "(" char
-                    name = line_before.strip(' ')
+                    name = str(line_before.strip(' '))
                     line_before, _, line_after = line_after.rstrip(' ').partition(')')  # Take the part of the string before and after the first ")" char
                     nodes = line_before.split(' ')
                     line_after = line_after.partition('PULSE')[2]  # Take the part of the string after the first "VALUE " chars
                     value = line_after.strip(' ( ) ')  # Strip spaces and bracket at the extremities
-                    self.circuit_data.Netlist[-1].type  = 'pulsed-source component'
-                    self.circuit_data.Netlist[-1].name  = str(name)
-                    self.circuit_data.Netlist[-1].nodes = nodes
-                    self.circuit_data.Netlist[-1].value = str(value)
+                    self.circuit_data.Netlist[name] = Component()
+                    self.circuit_data.Netlist[name].type  = 'pulsed-source component'
+                    self.circuit_data.Netlist[name].nodes = nodes
+                    self.circuit_data.Netlist[name].value = str(value)
                     continue
 
                 # Special case: Controlled-source component
@@ -225,31 +227,41 @@ class ParserPSPICE:
                 # F: Current-controlled current source
                 # G: Voltage-controlled current source
                 # H: Current-controlled voltage source
-                if ('VALUE ' in line) and ((line[0] == 'E') or (line[0] == 'F') or (line[0] == 'G') or (line[0] == 'H')):
+                # TODO Known issue: it fails to read correctly the nodes/parameters if the nodes contain brakets
+                # TODO Known issue: it fails to read correctly E/F/G/H where "VALUE" is not present
+                if ('VALUE' in line) and ((line[0] == 'E') or (line[0] == 'F') or (line[0] == 'G') or (line[0] == 'H')):
+                    # Find the correct delimiter to cover multiple syntaxes
+                    if 'VALUE = ' in line: delimiter_value = 'VALUE = '
+                    elif 'VALUE =' in line: delimiter_value = 'VALUE ='
+                    elif 'VALUE= ' in line: delimiter_value = 'VALUE= '
+                    elif 'VALUE=' in line: delimiter_value = 'VALUE='
+                    elif 'VALUE ' in line: delimiter_value = 'VALUE '
+
                     line_before, _, line_after = line.rstrip('\n').partition('(')  # Take the part of the string before and after the first "(" char
-                    name = line_before.strip(' ')
+                    name = str(line_before.strip(' '))
                     line_before, _, line_after = line_after.rstrip(' ').partition(')')  # Take the part of the string before and after the first ")" char
                     nodes = line_before.split(' ')
-                    line_after = line_after.partition('VALUE ')[2]  # Take the part of the string after the first "VALUE " chars
+                    line_after = line_after.partition(delimiter_value)[2]  # Take the part of the string after the first "delimiter_value" chars
                     value = line_after.strip(' { } ')  # Strip spaces and bracket at the extremities
-                    self.circuit_data.Netlist[-1].type  = 'controlled-source component'
-                    self.circuit_data.Netlist[-1].name  = str(name)
-                    self.circuit_data.Netlist[-1].nodes = nodes
-                    self.circuit_data.Netlist[-1].value = str(value)
+                    self.circuit_data.Netlist[name] = Component()
+                    self.circuit_data.Netlist[name].type  = 'controlled-source component'
+                    self.circuit_data.Netlist[name].nodes = nodes
+                    self.circuit_data.Netlist[name].value = str(value)
                     continue
 
                 # Special case: Parametrized component
                 if ('x' in line and line[0] == 'x') or ('X' in line and line[0] == 'X'):
                     self.flag_read_parametrized_component = True
                     line_before, _, line_after = line.rstrip('\n').partition('(')  # Take the part of the string before and after the first "(" char
-                    name = line_before.strip(' ')
+                    name = str(line_before.strip(' '))
                     line_before, _, line_after = line_after.rstrip(' ').partition(')')  # Take the part of the string before and after the first ")" char
                     nodes = line_before.split(' ')
                     value = line_after.strip(' { } ')  # Strip spaces and bracket at the extremities
-                    self.circuit_data.Netlist[-1].type  = 'parametrized component'
-                    self.circuit_data.Netlist[-1].name  = str(name)
-                    self.circuit_data.Netlist[-1].nodes = nodes
-                    self.circuit_data.Netlist[-1].value = str(value)
+                    self.name_last_component = name
+                    self.circuit_data.Netlist[name] = Component()
+                    self.circuit_data.Netlist[name].type  = 'parametrized component'
+                    self.circuit_data.Netlist[name].nodes = nodes
+                    self.circuit_data.Netlist[name].value = str(value)
                     continue
 
                 # Special case: Parameters of a parametrized component
@@ -259,14 +271,13 @@ class ParserPSPICE:
                     # line_split = line.rstrip('\n').split(':')  # Split line in two, before and after the "+ PARAMS:" command
                     # line_split = line_split[1].strip(' ')      # Take the second element and remove whitespaces at its extremities
                     line_split = line_split.split(' ')         # Split into different parameters
-                    self.circuit_data.Netlist[-1].parameters = {}
+                    self.circuit_data.Netlist[self.name_last_component].parameters = {}
                     for par in line_split:                     # Loop through the parameters
                         par_split = par.split('=')             # Split into name and value of the parameter
                         if len(par_split) == 2:                # Only take into account entries with two elements (for example, avoid None)
                             name_par = str(par_split[0].strip(' '))
                             value_par = str(par_split[1].strip(' { } '))  # Strip spaces and bracket at the extremities
-                            # self.circuit_data.Netlist[-1].parameters.append([str(name_par), str(value_par)])
-                            self.circuit_data.Netlist[-1].parameters[str(name_par)] = str(value_par)
+                            self.circuit_data.Netlist[self.name_last_component].parameters[str(name_par)] = str(value_par)
                     continue
                 elif self.flag_read_parametrized_component and '+' in line and line[0] == '+':  # This line defines additional parameters of the component
                     # Reminder: This type of line looks like this: + PARAMS: name1={value1} name2={value2} name3={value3}
@@ -277,8 +288,7 @@ class ParserPSPICE:
                         if len(par_split) == 2:                             # Only take into account entries with two elements (for example, avoid None)
                             name_par  = str(par_split[0].strip(' '))
                             value_par = str(par_split[1].strip(' { } '))  # Strip spaces and bracket at the extremities
-                            # self.circuit_data.Netlist[-1].parameters.append([str(name_par), str(value_par)])
-                            self.circuit_data.Netlist[-1].parameters[str(name_par)] = str(value_par)
+                            self.circuit_data.Netlist[self.name_last_component].parameters[str(name_par)] = str(value_par)
                     continue
 
                 # If this part of the code is reached, the line defines standard component
@@ -287,10 +297,10 @@ class ParserPSPICE:
                 line_before, _, line_after = line_after.rstrip(' ').partition(')')  # Take the part of the string before and after the first ")" char
                 nodes = line_before.split(' ')
                 value = line_after.strip(' { } ')  # Strip spaces and bracket at the extremities
-                self.circuit_data.Netlist[-1].type  = 'standard component'
-                self.circuit_data.Netlist[-1].name  = str(name)
-                self.circuit_data.Netlist[-1].nodes = nodes
-                self.circuit_data.Netlist[-1].value = str(value)
+                self.circuit_data.Netlist[name] = Component()
+                self.circuit_data.Netlist[name].type = 'standard component'
+                self.circuit_data.Netlist[name].nodes = nodes
+                self.circuit_data.Netlist[name].value = str(value)
 
         # Simplify options keys if they have default values
         if self.circuit_data.Options.options_simulation == get_default_options():
@@ -328,6 +338,7 @@ class ParserPSPICE:
         self.flag_read_autoconverge = False
         self.flag_read_time_schedule = False
         self.flag_read_probe = False
+        self.name_last_component = None  # this is used to have the name of the latest added component (used to read the parameters of parametrized component over multiple rows)
 
 
     def write2pspice(self, full_path_file_name: str, verbose: bool = False):
@@ -382,21 +393,25 @@ class ParserPSPICE:
 
         # Prepare netlist
         rows_netlist = []
-        # Check inputs
-        if not self.circuit_data.Netlist[0].type:
-            raise Exception('At least one netlist entry of known type must be added. Supported component types:\n' +
-                            '- comment\n' +
-                            '- standard component\n'
-                            '- stimulus-controlled component\n'
-                            '- controlled-source component\n'
-                            '- pulsed-source component\n'
-                            '- parametrized component\n'
-                            'Netlist cannot be generated.')
         rows_netlist.append(add_comment('**** Netlist ****'))  # Add header of this section
-        for s, component in enumerate(self.circuit_data.Netlist):
+        for s, name in enumerate(self.circuit_data.Netlist):
             # Read keys
-            name, nodes, value, parameters, type = \
-                component.name, component.nodes, component.value, component.parameters, component.type
+            type        = self.circuit_data.Netlist[name].type
+            nodes       = self.circuit_data.Netlist[name].nodes
+            value       = self.circuit_data.Netlist[name].value
+            parameters  = self.circuit_data.Netlist[name].parameters
+            # name, nodes, value, parameters, type = component.name, component.nodes, component.value, component.parameters, component.type
+
+            # Check inputs
+            if not type:
+                raise Exception('At least one netlist entry of known type must be added. Supported component types:\n' +
+                                '- comment\n' +
+                                '- standard component\n'
+                                '- stimulus-controlled component\n'
+                                '- controlled-source component\n'
+                                '- pulsed-source component\n'
+                                '- parametrized component\n'
+                                'Netlist cannot be generated.')
 
             # Add the relevant row depending on the component type
             if type == 'comment':
@@ -428,7 +443,7 @@ class ParserPSPICE:
                 if verbose: print('Netlist entry {} in position #{} is treated as a parametrized component.'.format(name, s + 1))
                 rows_netlist.append(add_parametrized_component(name, nodes, value, parameters))
             else:
-                raise Exception ('Netlist entry {} in position #{} has an unknown type: {}.'.format(component.name, s+1, type))
+                raise Exception ('Netlist entry {} in position #{} has an unknown type: {}.'.format(name, s+1, type))
 
         # Prepare options - Simulation options
         rows_options = []
@@ -549,10 +564,17 @@ class ParserPSPICE:
         :param verbose:
         :return:
         '''
+        # This hard-coded list defines the keys that will NOT be written in a single row in the output yaml file
+        list_exceptions = [
+            'additional_files',
+            'files_to_include',
+            'stimulus_files',
+            'component_libraries',
+            'variables',
+            ]
 
         all_data_dict = {**self.circuit_data.dict()}
-        with open(full_path_file_name, 'w') as outfile:
-            yaml.dump(all_data_dict, outfile, default_flow_style=False, sort_keys=False)
+        dict_to_yaml(all_data_dict, full_path_file_name, list_exceptions=list_exceptions)
         if verbose:
             print('New file ' + full_path_file_name + ' generated.')
 
@@ -917,9 +939,9 @@ def writeStimuliFromInterpolation(current_level: list, n_total_magnets: int, n_a
     # Interpolate data for each current level and ensure correct data format
     for k in current_level:
         if n_apertures == 2:
-            [time, data_R1, data_R2] = InterpolateResistance(k * 2, path_resources, n_apertures=n_apertures, Type = InterpolationType)
+            [time, data_R1, data_R2] = InterpolateResistance(k, path_resources, n_apertures=n_apertures, Type = InterpolationType)
         else:
-            [time, data_R1] = InterpolateResistance(k * 2, path_resources, n_apertures=n_apertures, Type=InterpolationType)
+            [time, data_R1] = InterpolateResistance(k, path_resources, n_apertures=n_apertures, Type=InterpolationType)
         if not R1.size > 0:
             R1 = data_R1[np.newaxis, ...]
         else:
